@@ -63,8 +63,8 @@ def dispy_provisional_result(result):
     """
 
     __dispy_job_reply = __dispy_job_info.job_reply
-    logger.debug('Sending provisional result for job %s to %s',
-                 __dispy_job_reply.uid, __dispy_job_info.reply_addr)
+    # logger.debug('Sending provisional result for job %s to %s',
+    #              __dispy_job_reply.uid, __dispy_job_info.reply_addr)
     __dispy_job_reply.status = DispyJob.ProvisionalResult
     __dispy_job_reply.result = result
     __dispy_job_reply.end_time = time.time()
@@ -76,6 +76,7 @@ def dispy_provisional_result(result):
         sock.connect(__dispy_job_info.reply_addr)
         sock.send_msg(serialize(__dispy_job_reply))
         ack = sock.recv_msg()
+        assert ack == 'ACK'
     except:
         logger.warning("Couldn't send provisional results %s:\n%s",
                        str(result), traceback.format_exc())
@@ -106,8 +107,7 @@ def _same_file(tgt, xf):
 
 def _dispy_job_func(__dispy_job_info, __dispy_job_certfile, __dispy_job_keyfile,
                     __dispy_job_args, __dispy_job_kwargs, __dispy_reply_Q,
-                    __dispy_job_name, __dispy_job_code,
-                    __dispy_path, __dispy_job_files=[]):
+                    __dispy_job_name, __dispy_job_code, __dispy_path, __dispy_job_files=[]):
     """Internal use only.
     """
     os.chdir(__dispy_path)
